gchecky.model.url_parameter_t

Package gchecky :: Module model :: Class url_parameter_t |
[hide private]
[frames] | no frames]

# Class url_parameter_t

source code

    object --+
             |
     gxml.Node --+
                 |
                url_parameter_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| name = `String:PATH(@name):REQ:EMPTY`
| type = `String:PATH(@type):REQ:EMPTY:VALS("buyer-id","order-id"`...``
| _fields = ``{``'``name``'``:` String:PATH(@name):REQ:EMPTY`,` `'``type``'``:` Strin`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### type Value:
      String:PATH(@type):REQ:EMPTY:VALS("buyer-id","order-id","order-subtota
      l","order-subtotal-plus-tax","order-subtotal-plus-shipping","order-tot
      al","tax-amount","shipping-amount","coupon-amount","billing-city","bil
      ling-region","billing-postal-code","billing-country-code","shipping-ci
      ty","shipping-region","shipping-postal-code","shipping-country-code")

  ### _fields list of meta-Fields of this class. Value:
      {'name': String:PATH(@name):REQ:EMPTY,
       'type': String:PATH(@type):REQ:EMPTY:VALS("buyer-id","order-id","orde
      r-subtotal","order-subtotal-plus-tax","order-subtotal-plus-shipping","
      order-total","tax-amount","shipping-amount","coupon-amount","billing-c
      ity","billing-region","billing-postal-code","billing-country-code","sh
      ipping-city","shipping-region","shipping-postal-code","shipping-countr
      y-code")}